==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/audiotoolbox/AudioQueueProperty.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.audiotoolbox;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.audiounit.*;
import org.robovm.apple.coreaudio.*;
import org.robovm.apple.coremidi.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Marshaler(ValuedEnum.AsMachineSizedUIntMarshaler.class)/*</annotations>*/
public enum /*<name>*/AudioQueueProperty/*</name>*/ implements ValuedEnum {
    /*<values>*/
    IsRunning(1634824814L),
    SampleRate(1634825074L),
    NumberChannels(1634821219L),
    CurrentDevice(1634820964L),
    MagicCookie(1634823523L),
    MaximumOutputPacketSize(2020569203L),
    StreamDescription(1634821748L),
    ChannelLayout(1634820972L),
    EnableLevelMetering(1634823525L),
    CurrentLevelMeter(1634823542L),
    CurrentLevelMeterDB(1634823524L),
    DecodeBufferSizeFrames(1684234854L),
    ConverterError(1902343781L),
    EnableTimePitch(1902081136L),
    TimePitchAlgorithm(1903456353L),
    TimePitchBypass(1903456354L),
    HardwareCodecPolicy(1634820976L),
    ChannelAssignments(1634820961L);
    /*</values>*/

    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<methods>*//*</methods>*/

    private final long n;

    private /*<name>*/AudioQueueProperty/*</name>*/(long n) { this.n = n; }
    public long value() { return n; }
    public static /*<name>*/AudioQueueProperty/*</name>*/ valueOf(long n) {
        for (/*<name>*/AudioQueueProperty/*</name>*/ v : values()) {
            if (v.n == n) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + n + " found in " 
            + /*<name>*/AudioQueueProperty/*</name>*/.class.getName());
    }
}

==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/audiotoolbox/AudioQueueProperty.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.audiotoolbox;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.coreaudio.*;
import org.robovm.apple.coremidi.*;
import org.robovm.apple.avfoundation.*;
import org.robovm.apple.uikit.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*//*</annotations>*/
public enum /*<name>*/AudioQueueProperty/*</name>*/ implements ValuedEnum {
    /*<values>*/
    IsRunning(1634824814L),
    SampleRate(1634825074L),
    NumberChannels(1634821219L),
    CurrentDevice(1634820964L),
    MagicCookie(1634823523L),
    MaximumOutputPacketSize(2020569203L),
    StreamDescription(1634821748L),
    ChannelLayout(1634820972L),
    EnableLevelMetering(1634823525L),
    CurrentLevelMeter(1634823542L),
    CurrentLevelMeterDB(1634823524L),
    DecodeBufferSizeFrames(1684234854L),
    ConverterError(1902343781L),
    EnableTimePitch(1902081136L),
    TimePitchAlgorithm(1903456353L),
    TimePitchBypass(1903456354L),
    HardwareCodecPolicy(1634820976L),
    ChannelAssignments(1634820961L);
    /*</values>*/

    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<methods>*//*</methods>*/

    private final long n;

    private /*<name>*/AudioQueueProperty/*</name>*/(long n) { this.n = n; }
    public long value() { return n; }
    public static /*<name>*/AudioQueueProperty/*</name>*/ valueOf(long n) {
        for (/*<name>*/AudioQueueProperty/*</name>*/ v : values()) {
            if (v.n == n) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + n + " found in " 
            + /*<name>*/AudioQueueProperty/*</name>*/.class.getName());
    }
}
